@@ -20,6 +20,7 @@ if home := os.getenv('BCISTREAM_HOME'):
 
 from datetime import datetime, timedelta
 from openbci_stream.utils import HDF5Writer
+from openbci_stream.utils.pid_admin import autokill_process
 import numpy as np
 
 from bci_framework.extensions import properties as prop
@@ -27,6 +28,8 @@ from bci_framework.extensions.data_analysis.utils import loop_consumer
 
 KafkaStream = TypeVar('kafka-stream')
 
+autokill_process(name=f'bci-framework_records')
+
 
 ########################################################################
 class RecordTransformer:
